//Функция генерации обучающих данных (для динамики выходных характеристик)
function [SystemOutputCharacteristics,...//Выходные характеристики
          SystemParametrsNames,...//Имена параметров системы
          SystemParametrsValues...//Значения параметров системы
          ]=AdvancedModelLearningDataDynamicWithGenericParametrs(GenericParametrsNames,...//Имена параметров, определяющих динамику
                                                                 GenericParametrsValues,...//Значения параметров, определяющих динамику
                                                                 systemAttributes...//Аттрибуты системы
                                                                 )
    //Проверяем аргументы
    if argn(2) ~= 3 then
        error('Function AdvancedModelLearningDataDynamicWithGenericParametrs takes 3 arguments');
        return;
    end
    
    //Проверяем корректность аргументов
    sizeGenericParametrsNames = size(GenericParametrsNames);
    if (type(GenericParametrsNames) ~= 10) || (sizeGenericParametrsNames(1) ~= 1) then
        error('The first argument of function AdvancedModelLearningDataDynamicWithGenericParametrs is string matrix 1xM');
        return;
    end
    if isempty(GenericParametrsValues) ||...
       (type(GenericParametrsValues) ~= 1) then
        error('The second argument of function AdvancedModelLearningDataDynamicWithGenericParametrs is real matrix NxM');
        return;
    end
    sizeGenericParametrsValues = size(GenericParametrsValues);
    if sizeGenericParametrsValues(2) ~= sizeGenericParametrsNames(2) then
        error('The first and second arguments of function AdvancedModelLearningDataDynamicWithGenericParametrs are matrixes with same columns');
        return;
    end
    if (type(systemAttributes) ~= 17) ||...
       (typeof(systemAttributes) ~= 'SystemAttributes') &&...
       (typeof(systemAttributes) ~= 'SystemAttributesControlMode') then
        error('The third argument of function AdvancedModelLearningDataDynamicWithGenericParametrs is system attribute type');
        return;
    end
    if sizeGenericParametrsValues(1) ~= size(systemAttributes.SystemParametrsValues)(1) then
        error('The second argument of function AdvancedModelLearningDataDynamicWithGenericParametrs and individual system parametrs matrix are matrixes with same rows');
        return;
    end
    
    //Формируем входные данные
    SystemParametrsNames = [GenericParametrsNames, systemAttributes.SystemParametrsNames];//Имена параметров системы
    SystemParametrsValues = [GenericParametrsValues, systemAttributes.SystemParametrsValues];//Величины параметров системы
    
    //Проводим вычислительные эксперименты
    SystemOutputCharacteristics = AdvancedModelLearningDataDynamic(SystemParametrsNames,...//Имена параметров, определяющих динамику
                                                                   SystemParametrsValues,...//Значения параметров, определяющих динамику
                                                                   systemAttributes.SystemOutputCharacteristicsNames,...//Имена выходных характеристик системы
                                                                   systemAttributes.SystemOutputCharacteristicsNamesIndexes,...//Индексы выходных характеристик системы
                                                                   systemAttributes.SystemOutputCharacteristicsIndexes,...//Индексы выходных характеристик системы (в именах)
                                                                   systemAttributes.SystemShemaName,...//Имя схемы системы
                                                                   systemAttributes.SystemOutputCharacteristicsCompressionFunctions...//Функция сжатия динамики
                                                                   );
endfunction
