//Моделируем динамику
function [SystemOutputChatacteristics...//Выходные характеристики системы
          ]=ComputingExperiment(SystemParametrsNames,...//Имена параметров
                                SystemParametrsValues,...//Значения параметров
                                SystemOutputChatacteristicsNames,...//Имена выходных характеристик системы
                                SystemShema...//Схема системы
                                )//Моделирование возможных динамик
    //Проверяем число аргументов
    nArgs = argn(2);
    if (nArgs ~= 2) && (nArgs ~= 4) then
        error('Function ComputingExperiment takes 2 or 4 arguments');
        return;
    end
    
    //Проверяем корректность типов данных аргументов
    if nArgs == 4 then
        if ~isempty(SystemParametrsNames) && (type(SystemParametrsNames) ~= 10) then
            error('The first argument of ComputingExperiment function is array of string');
            return;
        end
        if type(SystemParametrsValues) ~= 1 then
            error('The second argument of ComputingExperiment function is array of real or system sheme diagram type exemplar]');
            return;
        end
        sizeSystemParametrsNames = size(SystemParametrsNames);
        if or(sizeSystemParametrsNames ~= size(SystemParametrsValues)) ||...
           (sizeSystemParametrsNames(1) ~= 1) then
            error('The first and second arguments of ComputingExperiment function (if this function has 4 arguments) are matrixes same dimencions 1xM');
            return;
        end
    end
    if type(SystemOutputChatacteristicsNames) ~= 10 then
        error('The first and third arguments of ComputingExperiment function is array of string');
        return;
    end
    if type(SystemShema) ~= 128 then
        error('The second (if two argument) 4th (if four argument) argument of ComputingExperiment function is array of system sheme diagram type exemplar');
        return;
    end
    
    //Задаем параметры системы
    if nArgs == 4 then
        SystemShema.props.context = SetContext(SystemParametrsNames,...//Имена параметров
                                               SystemParametrsValues,...//Значения параметров
                                               SystemShema.props.context...//Задаваемый контекст
                                               );
    end
    SystemShema.props.tol(5) = 0.0;//Отключаем реальное время
                                           
    //Запускаем моделирование динамики
    xcos_simulate(SystemShema, 4);
    
    //Получаем значения выходных характеристик системы
    SystemOutputChatacteristics = evstr(SystemOutputChatacteristicsNames);
endfunction

//Вспомогательные функции
function [context]=SetContext(ParametrsNames,...//Имена параметров
                              ParametrsValues,...//Значения параметров
                              context...//Задаваемый контекст
                              )//задаем контекст
    //Проверяем аргументы
    if isempty(ParametrsNames) || isempty(ParametrsValues) || isempty(context) then
        return;
    end
    
    //Выделяем из контекста имена величин
    contextNames = stripblanks(strsplit(strcat(context, ' = '), '=')(1:2:2*size(context, '*')));
    
    //Приравниваем именам величин их значения
    parametrs = ParametrsNames + '=' + string(ParametrsValues);
    
    //Определяем индексы заданных величин в контексте
    parametrsNames = stripblanks(ParametrsNames);
    indexes = Find(parametrsNames, contextNames);
    
    //Заполняем контекст
    context(indexes) = parametrs;
endfunction
